from lammps_logfile import File
from lammps_logfile import running_mean
import argparse
import matplotlib.pyplot as plt

def get_args():
    parser = argparse.ArgumentParser(description="Plot contents from lammps log files")
    parser.add_argument("input_file", type=str)
    parser.add_argument("-x", type=str, default="Time")
    parser.add_argument("-y", type=str, nargs="+")
    parser.add_argument("-a", "--running_average", type=int, default=1)
    args = parser.parse_args()
    return args

def run():
    args = get_args()
    log = File(args.input_file)
    x = log.get(args.x)
    print(x)
    for y in args.y:
        data = log.get(y)
        print(data)

        if args.running_average >= 2:
            x = running_mean(x, args.running_average)
            data = running_mean(data, args.running_average)

        plt.plot(x, data, label=y)
    plt.legend()
    plt.show()
    



import numpy as np 
import matplotlib 

def running_mean(data, N):
    """Calculate running mean of an array-like dataset.

    Parameters 
    --------------------
    :param data: The array 
    :type data: 1d array-like
    :param N: Width of the averaging window
    :type N: int 

    """
    
    data = np.asarray(data)
    if N == 1:
        return data
    else:
        retArray = np.zeros(data.size)*np.nan
        padL = int(N/2)
        padR = N-padL-1
        retArray[padL:-padR] = np.convolve(data, np.ones((N,))/N, mode='valid')
        return retArray 

def get_color_value(value, minValue, maxValue, cmap='viridis'):
    """Get color from colormap.

    Parameters
    -----------------
    :param value: Value used tpo get color from colormap
    :param minValue: Minimum value in colormap. Values below this value will saturate on the lower color of the colormap.
    :param maxValue: Maximum value in colormap. Values above this value will saturate on the upper color of the colormap.

    :returns: 4-vector containing colormap values. 

    This is useful if you are plotting data from several simulations, and want to color them based on some parameters changing between the simulations. For example, you may want the color to gradually change along a clormap as the temperature increases. 

    """
    diff = maxValue-minValue
    cmap = matplotlib.cm.get_cmap(cmap)
    rgba = cmap((value-minValue)/diff)
    return rgba

def get_matlab_color(i):
    """Get colors from matlabs standard color order. 

    Parameters
    -------------
    :param i: Index. Cycles with a period of 7, so calling with 1 returns the same color as calling with 8. 
    :type i: int 

    :returns: color as 3-vector 

    """
    colors = np.asarray([ [0, 0.447000000000000, 0.741000000000000],
                          [0.850000000000000, 0.325000000000000, 0.098000000000000],
                          [0.929000000000000, 0.694000000000000, 0.125000000000000],
                          [0.494000000000000, 0.184000000000000, 0.556000000000000],
                          [0.466000000000000, 0.674000000000000, 0.188000000000000],
                          [0.301000000000000, 0.745000000000000, 0.933000000000000],
                          [0.635000000000000, 0.078000000000000, 0.184000000000000]])
    return colors[ i%len(colors) ]
